lonFormatVersion top-level constant
int
const lonFormatVersion
The normative Language Object Notation version implemented by this package.
Implementation
const lonFormatVersion = 1;
The normative Language Object Notation version implemented by this package.
const lonFormatVersion = 1;